==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetMECRolePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property name The role name.
 * @property resourceGroupName The resource group name.
 */
public data class GetMECRolePlainArgs(
    public val deviceName: String,
    public val name: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetMECRolePlainArgs].
 */
@PulumiTagMarker
public class GetMECRolePlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("iahilguwgcjrvljl")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The role name.
     */
    @JvmName("tqmccvjubjtosyca")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("aiwajtfhjuoeegek")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetMECRolePlainArgs = GetMECRolePlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        name = name ?: throw PulumiNullFieldException("name"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetMECRolePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property name The role name.
 * @property resourceGroupName The resource group name.
 */
public data class GetMECRolePlainArgs(
    public val deviceName: String,
    public val name: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetMECRolePlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetMECRolePlainArgs].
 */
@PulumiTagMarker
public class GetMECRolePlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("fjwxkvcgxgopskev")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The role name.
     */
    @JvmName("hxkqakcecqdnhnae")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("xicsyyvghlbfhmxx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetMECRolePlainArgs = GetMECRolePlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        name = name ?: throw PulumiNullFieldException("name"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
